@@ -2,11 +2,11 @@
 #######################################################################
 """The converterregexp class.
 
-$Id: converterregexp.py 49773 2008-01-03 13:40:06Z cray $
+$Id: converterregexp.py 52439 2009-02-01 11:37:53Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49773 $"
+__version__ = "$Revision: 52439 $"
 
 from zope.interface import implements
 from interfaces import IConverterRegexp
@@ -19,8 +19,8 @@ class EDict(object) :
     d = {}
     def __init__(self,d={},**kw) :
         self.d = {}
-        self.d = dict([ (str(x),str(y)) for x,y in d.items()] )
-        self.d['quote'] = lambda x : quote(x)
+        self.d = dict([ (str(x),y) for x,y in d.items()] )
+        self.d['quote'] = lambda x : quote(str(x))
             
 
     def __getitem__(self,name) :
