@@ -2,11 +2,11 @@
 #######################################################################
 """The mapperobject class.
 
-$Id: mapperobject.py 49773 2008-01-03 13:40:06Z cray $
+$Id: mapperobject.py 53274 2009-06-13 17:46:54Z cray $
 """
 __author__  = "Ischenko Valera, 2006"
 __license__ = "GPL"
-__version__ = "$Revision: 49773 $"
+__version__ = "$Revision: 53274 $"
 
 from zope.interface import implements
 from zope.interface import providedBy
@@ -39,7 +39,7 @@ class MapperObject(BTreeContainer):
             raise ValueError
 
     def lookup(self, ob):
-        all_interfaces = [interface.interfaceToName(ob,a) for a in providedBy(ob)]
+        all_interfaces = [a.__module__ + "." + a.__name__ for a in providedBy(ob)]
         d = {}
         
         for key in all_interfaces :
